from .. import Provider as JobProvider


class Provider(JobProvider):
    """Translated from Super class"""

    jobs = (
        "Administrátor, umění",
        "Administrátor, státní služba",
        "Advokát",
        "Advokát pro ochranné známky",
        "Akademický knihovník",
        "Akupunkturista",
        "Analytický chemik",
        "Analytik finančního rizika",
        "Angličtina jako lektorka cizího jazyka",
        "Angličtina jako učitel druhého jazyka",
        "Animátor",
        "Arborista",
        "Archeológ",
        "Architekt",
        "Architektonický technológ",
        "Archivář",
        "Arteterapeut",
        "Asistent politika",
        "Astronóm",
        "Audiologický vědec",
        "Automobilový inženýr",
        "Autorizovaný likvidátor ztrát",
        "Autorizovaný účetní",
        "Autorizovaný účetní v oblasti veřejných financí",
        "Bankéř",
        "Báňský inženýr",
        "Barista",
        "Biochemik, klinický",
        "Biomedicínsky inženýr",
        "Biomedicínsky vědec",
        "Bylinkář",
        "Bytový manažér / referent",
        "Charitatívní úředník",
        "Chemický inženýr",
        "Chemik, analytický",
        "Chiropraktik",
        "Chirurg",
        "Copywriter, reklama",
        "Cytogenetik",
        "Daňový poradce",
        "Dětská sestra",
        "Dětský psychoterapeut",
        "Diagnostický rádiograf",
        "Dietológ",
        "Dyzajnér, foukané sklo / vitráž",
        "Dyzajnér, grafik",
        "Dyzajnér, interiér / protor",
        "Dyzajnér, keramika / hrčířství",
        "Dyzajnér, multimédiá",
        "Dyzajnér, móda / oblečení",
        "Dyzajnér, nábytek",
        "Dyzajnér, průmyslový / produkt",
        "Dyzajnér, televíize / film",
        "Dyzajnér, textil",
        "Dyzajnér, výstava / výstava",
        "Dyzajnér, šperky",
        "Docent",
        "Dodávateľ",
        "Dospělý poradentský pracovník",
        "Dozorce",
        "Dramatický terapeut",
        "Důstojník obchodního námořníctví",
        "Důstojník pro ochranu přírody",
        "Důstojník pro výcvik a vzdělávní ozbrojených síl",
        "Editor funkcie časopisu",
        "Ekológ",
        "Ekonom",
        "Elektroinženýr",
        "Embryológ, klinický",
        "Energetický inženýr",
        "Energetický manažér",
        "Environmentálny manažér",
        "Ergonóm",
        "Barevný technológ",
        "Farmaceut Spoločenstva",
        "Farmakológ",
        "Filmový / video editor",
        "Finanční kontrolor",
        "Finanční manažér",
        "Finanční obchodník",
        "Finanční plánovač",
        "Finanční poradce",
        "Finanční ředitel",
        "Firemní sekretářka",
        "Fotograf",
        "Fytoterapeut",
        "Fyzik zdraví",
        "Fyzik, lékař",
        "Fyziologický vědec",
        "Fyziológ cvičení",
        "Fyzioterapeut",
        "Foukač akla / dyzajnér",
        "Genetik, molekulárny",
        "Geochemik",
        "Geodet minerálu",
        "Geodet pojištění rizika",
        "Geofyzik / terénní seismológ",
        "Geológ, strojař",
        "Geológ",
        "Geovedec",
        "Grafický dyzajnér",
        "Grafik",
        "Hasič",
        "Hematológ",
        "Herec",
        "Herpetológ",
        "Hlavní marketingový ředitel",
        "Homeopat",
        "Hotelový manažér",
        "Hudebník",
        "Hudební lektor",
        "Hudební terapeut",
        "Hutník",
        "Hydrogeológ",
        "Hydrografický geodet",
        "Hydrológ",
        "Hygienik práce",
        "IT konzultant",
        "Ilustrátor",
        "Imunológ",
        "Informační úředník",
        "Investiční analytik",
        "Investiční bankář, funkční",
        "Investiční bankář, podnikový",
        "Inspektor / hodnotitel reklamací",
        "Inspektor historických budov / referent památkové ochrany",
        "Inspektor plánovaní a rozvoje",
        "Inspektor zdraví a bezpečnosti",
        "Inženýr budov",
        "Inženýr elektroniky",
        "Inženyr kontroly a přístrojového vybavení",
        "Inženýr zemědělství",
        "Inženýr pro automobilový průmysl",
        "Inženýr výrobních systémovů",
        "Inženýr, bankovnictví",
        "Inženýr, biomedicíny",
        "Inženýr, chemický",
        "Inženýr, elektronika",
        "Inženýr, elektrotechnik",
        "Inženýr, energie",
        "Inženýr, komunikace",
        "Inženýr, letecký",
        "Inženýr, materiály",
        "Inženýr, pozemky",
        "Inženýr, zemědělství",
        "Inženýr, řízení a přístrojové vybavení",
        "Inženýr, ropa",
        "Inženýr, statik",
        "Inženýr, stavební služby",
        "Inženýr, stavební (smluvní)",
        "Inženýr, stavební inženier (poradenství)",
        "Inženýr, technický prodej",
        "Inženýr, voda",
        "Inženýr, vysílání (provoz)",
        "Inženýr, výroba",
        "Inženýr, výroba",
        "Inženýr, výrobní systémy",
        "Inženýr, vrtaní",
        "Inženýr, web",
        "Inženýr, údržba",
        "Inženýr, údržba (IT)",
        "Inženýrský geológ",
        "Kameraman",
        "Kariérní informační úředník",
        "Kariérní poradce",
        "Kariérní poradce pro vysokoškolské vzdělání",
        "Kartograf",
        "Klinický biochemik",
        "Klinický cytogenetik",
        "Klinický embryológ",
        "Klinický molekulárny genetik",
        "Klinický psychológ",
        "Klinický vědec, histokompatibilita a imunogenetika",
        "Knihovník",
        "Knihovník, veřejný",
        "Kníhkupec",
        "Komerční / rezidenční geodet",
        "Komerční záhradník",
        "Komunikační inženýr",
        "Komunitní umělecký pracovník",
        "Jednatel spoločnosti",
        "Kontrolór",
        "Konzervátor / restauratér nábytku",
        "Konzervátor muzea / galérie",
        "Konzervátor, muzeum / galéria",
        "Konzervátor, nábytku",
        "Konzultant pro důchody",
        "Konzultace se stavebním inženýrem",
        "Koordinátor dobrovolnictví",
        "Kupující, maloobchod",
        "Kurátor",
        "Kurátor muzea / galérie",
        "Lektor dalšího vzdělávání",
        "Lektor, vysokoškolské vzdělání",
        "Lektor, další vzdělání",
        "Lékař všeobecného lekařství",
        "Lékař, nemocnice",
        "Lékař, všeobecná praxe",
        "Lékárnik, komunita",
        "Lékárnik, nemocnice",
        "Lékářsky fyzik",
        "Lékářsky ilustrátor",
        "Lékářsky obchodní zástupca",
        "Lékářsky sekretář",
        "Lékářsky technický pracovník",
        "Letecký dispečer",
        "Letecký inženýr",
        "Letecký sprostředkovateľ",
        "Lexikograf",
        "Licencovaný dopravce",
        "Lobista",
        "Logistika / podpora / administratívní důstojník ozbrojených síl",
        "Manažér call centra",
        "Manažér cestovní kanceláře",
        "Manažér divadelní scény",
        "Manažér farmy",
        "Manažér fitnescentra",
        "Manažér informačných systému",
        "Manažér komerční umělecké galérie",
        "Manažér logistiky a distribuce",
        "Manažér stravování",
        "Manažér umělecké galérie",
        "Manažér zařízení",
        "Manažér zábavného parku",
        "Manžérsky konzultant",
        "Marketingový manažér",
        "Materiálový inženýr",
        "Mediální plánovač",
        "Meteorológ",
        "Mikrobiológ",
        "Moderátor, vysílání",
        "Mořský vědec",
        "Multimediální programy",
        "Módní návrhář",
        "Nemocniční lékař",
        "Nemocniční lekárniík",
        "Neurochirurg",
        "Novinář novín",
        "Novinář časopisu",
        "Novinář, noviny",
        "Novinář, vysílání",
        "Novinář, časopis",
        "Nákupčí médií",
        "Nákupčí, průmyslu",
        "Námořní architekt",
        "Návrhář interiérů a prostor",
        "Návrhář nábytku",
        "Návrhář výstavy",
        "Návrhář šperkov",
        "Návrhářka keramiky",
        "Obchodník s akciemi",
        "Obchodník s dluhopisy",
        "Obchodník s futures",
        "Oceánograf",
        "Ochranář, historické budovy",
        "Odborník na životní prostředí",
        "Oděvní / textilní technológ",
        "Onkológ",
        "Operatívní výzkumník",
        "Operační důstojních diplomatických služeb",
        "Operačn důstojník ozbrojených síl",
        "Optik, výdej",
        "Optometrista",
        "Ortoptista",
        "Osobní asistent",
        "Osteopat",
        "Oční lékař",
        "Palubní průvodce",
        "Patent attorney",
        "Patológ",
        "Pedagogický psychológ",
        "Pedikér",
        "Personalista",
        "Pilot letecké společnosti",
        "Plánovač dopravy",
        "Plánovač reklamního účtu",
        "Plánovač tisku",
        "Podnikový investiční bankéř",
        "Podnikový pokladník",
        "Pojistný matematik",
        "Pojišťovací makléř",
        "Pojišťovák",
        "Police officer",
        "Poradce pro zdraví a bezpečnosť",
        "Poradce pro životní prostředí",
        "Poradenský pracovník",
        "Poradenský psychológ",
        "Potravinářsky technológ",
        "Zemědělský konzultant",
        "Pracovník medzinárodní pomoci / rozvoje",
        "Pracovník pomoci",
        "Pracovník rozvoje komunity",
        "Pracovník s mládeží",
        "Pracovní psychológ",
        "Pracovní terapeut",
        "Predejce",
        "Překladateľ",
        "Prevozovatel televizní kamery",
        "Provozní geológ",
        "Provozní investiční bankéř",
        "Provozní ředitel",
        "Průmyslový / produktový dizajnér",
        "Průmyslový kupující",
        "Průzkumník trhu",
        "Probační úředník",
        "Producent, rádio",
        "Producent, televize / film / video",
        "Production assistant, radio",
        "Production assistant, televize",
        "Production designer, theatre/television/film",
        "Production engineer",
        "Production manager",
        "Produktový dizajnér",
        "Produktový manažér",
        "Professor Emeritus",
        "Programátor, applikací",
        "Programátor, multimedia",
        "Programátor, systems",
        "Korektor",
        "Právnik",
        "Právní tajemník",
        "Psychiatrická sestra",
        "Psychitr",
        "Psycholog, klinický",
        "Psycholog, poradenství",
        "Psycholog, vzdělání",
        "Psycholog, forézní",
        "Psycholog, pracovní",
        "Psycholog, vězeňské a probační služby",
        "Psycholog, sport a cvičení",
        "Psychoterapeut tanečního pohybu",
        "Psychoterapeut",
        "Porodní asistentka",
        "Manažér kvality",
        "Poradce",
        "Realitní makléř",
        "Redaktor, uvedení do provozu",
        "Redakční asistent",
        "Referent cestovního ruchu",
        "Referent environmentální výchovy",
        "Referent geografických informačných systému",
        "Referent komunitního vzdělávání",
        "Referent múzejního vzdělávání",
        "Referent obchodních norem",
        "Referent ochrany přírody",
        "Referent odborné přípravy a rozvoje",
        "Referent odborového výzkumu",
        "Referent zemědělských pokusu",
        "Referent pro nouzové plánování / řízení",
        "Referent pro výstavy v muzeich / galeriich",
        "Referent rozvoje umění",
        "Referent technické podpory IT",
        "Referent výstavy, muzeum / galérii",
        "Referent lidských zdrojů",
        "Školní referent, komunita",
        "Školení referent, muzeum",
        "Regulátor ztrát, objednaný",
        "Reklamní textař",
        "Reklamní umělecký ředitel",
        "Ředitel pro stretegii",
        "Ropný inženýr",
        "Rozvojový pracovník, komunita",
        "Rozvojový pracovník, mezinárodní pomoc",
        "Sanitka",
        "Sestra pro dospělé",
        "Sestra pro duševní zdraví",
        "Sestra s poruchami učení",
        "Sestra, dětská",
        "Sestra, dospělý",
        "Sestra, porucha učení",
        "Sietový inženýr",
        "Spisovateľ",
        "Spolupracovník pro klinický výzkum",
        "Spracovatel geofyzikálnych údajů",
        "Spravodajský analytik",
        "Správce",
        "Správce databázy",
        "Správce dědictví",
        "Správce duchodového systému",
        "Správce lesů",
        "Správce nemovitostí / pozemkový agent",
        "Správce pojisných účtu",
        "Správce polohy",
        "Správce zpracovaní údajů",
        "Správce umění",
        "Správce zákazníckého centra",
        "Správce školní",
        "Správce státní služby",
        "Správce, charitatívní / dobrovolnické organizáce",
        "Správce, místní samospráva",
        "Správce, vzdělávání",
        "Správce, sport",
        "Stavební geodet",
        "Stavební inženýr, poradenství",
        "Stavební inženýr, uzavírání smluv",
        "Střihač, film / video",
        "Strojní inženýr",
        "Strážce",
        "Osvětlovací technik, vysílání / film / video",
        "Soudce psychológ",
        "Soudní vědec",
        "Soukromý učitel hudby",
        "Tanečnice",
        "Technický důstojník ozbrojených síl",
        "Technik údržby",
        "Technológ pro zvířata",
        "Technológ vaření piva",
        "Terapeut, drama",
        "Terapeut, hudba",
        "Terapeut, záhradnícký",
        "Terapeut, sport",
        "Terénní seismológ",
        "Tlumočník",
        "Toxikológ",
        "Umělec",
        "Učicí se mentor",
        "Učitel, angličtina jako cizí jazyk",
        "Učitel, hudba",
        "Učitel, vzdělání dospělých",
        "Učitel, základní škola",
        "Učitel na základní škole",
        "Vědec pro kvalitu vody",
        "Vědec vývoj produktů / procesů",
        "Vědecký pracovník lékařské laboratoře",
        "Vedoucí kanceláře",
        "Vedoucí konferenčního centra",
        "Vedoucí osobní dopravy",
        "Vedoucí outdoorových aktivít / vzdělávání",
        "Vedoucí reklamního účtu",
        "Vedoucí restaurace rychlého občerstvení",
        "Vedoucí rybí farmy",
        "Vedoucí skladu",
        "Vedoucí střediska volného času",
        "Vedoucí turistického informačného centra",
        "Vedoucí ubytování",
        "Vedoucí zdravotní služby",
        "Vedoucí úseku",
        "Veterinární chirurg",
        "Video editor",
        "Vizuální obchodník",
        "Vládní úředník pro sociální výzkum",
        "Vodní inženýr",
        "Vrtný inženýr",
        "Zprostředkovatel pojistných událostí",
        "Vysokoškolský lektor",
        "Výkonný ředitel",
        "Výkonný technický ředitel",
        "Výrobní inženýr",
        "Výtvarný umělec",
        "Vývojář aplikací",
        "Vývojář her",
        "Vývojář počítačových her",
        "Vývojář systémů",
        "Výživový poradca pro zvířata",
        "Výživový terapeut",
        "Web designer",
        "Zaměstnanec imigračního úřadu",
        "Zdravotní sestra, duševní zdraví",
        "Zeměměřič / geomatik",
        "Zmluvní stavební inženýr",
        "Zubař",
        "Záchranář",
        "Záhradnícký konzultant",
        "Záhradnícký terapeut",
        "Záhradník, komerční",
        "Záhradní architekt",
        "Úředník místní samosprávy",
        "Úřadník pro rybolov",
        "Účetní, autorizované veřejné finance",
        "Účetní, autorizovaný",
        "Účetní, autorizovaný / certifikovaný",
        "Účetní technik",
        "Specialista na multimédiá",
        "Specialista na podporu zdraví",
        "Dopravce",
        "Šlechtitel rostlin / genetik",
    )

    def job(self) -> str:
        return self.random_element(self.jobs)
