from .. import Provider as BaseProvider


# Reference:
# https://th.wikipedia.org/wiki/หมวดหมู่:บุคคลแบ่งตามอาชีพ
# on 2018-10-16, slightly edited and add few more jobs
class Provider(BaseProvider):
    jobs = (
        "กวี",
        "เกษตรกร",
        "ข้าราชการ",
        "คนขับรถแท็กซี่",
        "ค้าขาย",
        "โฆษก",
        "จ๊อกกี้",
        "จิตรกร",
        "เจ้าหน้าที่พัฒนาเอกชน",
        "เจ้าหน้าทีรักษาความปลอดภัย",
        "เจ้าหน้าที่รัฐบาล",
        "ช่างทำเครื่องดนตรี",
        "ช่างทำผม",
        "ตำรวจ",
        "ทนายความ",
        "ทหารบก",
        "นักกฎหมาย",
        "นักการกุศล",
        "นักการทูต",
        "นักการเมือง",
        "นักการศึกษา",
        "นักกีฬา",
        "นักเขียน",
        "นักคณิตศาสตร์",
        "นักเคลื่อนไหว",
        "นักจัดรายการวิทยุ",
        "นักจิตวิทยา",
        "นักชีววิทยา",
        "นักดนตรี",
        "นักดาราศาสตร์",
        "นักแต่งเพลง",
        "นักถ่ายภาพ",
        "นักธุรกิจ",
        "นักบวช",
        "นักบิน",
        "นักบินอวกาศ",
        "นักโบราณคดี",
        "นักประชาสัมพันธ์",
        "นักประดิษฐ์",
        "นักประวัติศาสตร์",
        "นักปรัชญา",
        "นักแปล",
        "นักผจญภัย",
        "นักพจนานุกรม",
        "นักพากย์",
        "นักภาษาศาสตร์",
        "นักโภชนาการ",
        "นักมายากล",
        "นักวาดการ์ตูน",
        "นักวิจัย",
        "นักวิทยาศาสตร์",
        "นักเศรษฐศาสตร์",
        "นักสะสมศิลปะ",
        "นักสังคมวิทยา",
        "นักสังคมศาสตร์",
        "นักสังคมสงเคราะห์",
        "นักสัตววิทยา",
        "นักสำรวจ",
        "นักสิทธิมนุษยชน",
        "นักสืบ",
        "นักแสดง",
        "นักหนังสือพิมพ์",
        "นักอนุรักษ์ธรรมชาติ",
        "นักออกแบบ",
        "นางแบบ",
        "นายแบบ",
        "บรรณาธิการ",
        "บรรณารักษ์",
        "โปรแกรมเมอร์",
        "ผู้กำกับ",
        "ผู้กำกับภาพยนตร์",
        "ผู้กำกับละครโทรทัศน์",
        "ผู้จัดพิมพ์",
        "พิธีกร",
        "แพทย์",
        "ภัณฑารักษ์",
        "เภสัชกร",
        "มัคคุเทศก์",
        "วิศวกร",
        "วีเจ",
        "ศิลปิน",
        "สถาปนิก",
        "อัยการ",
        "อาจารย์",
    )
